==> zio-aws-docdb_2.13-5.17.104.13-sources.jar: zio/aws/docdb/model/DescribeOrderableDbInstanceOptionsResponse.scala <==
package zio.aws.docdb.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DescribeOrderableDbInstanceOptionsResponse(
    orderableDBInstanceOptions: Option[
      Iterable[zio.aws.docdb.model.OrderableDBInstanceOption]
    ] = None,
    marker: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.docdb.model.DescribeOrderableDbInstanceOptionsResponse = {
    import DescribeOrderableDbInstanceOptionsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.docdb.model.DescribeOrderableDbInstanceOptionsResponse
      .builder()
      .optionallyWith(
        orderableDBInstanceOptions.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.orderableDBInstanceOptions)
      .optionallyWith(marker.map(value => value: java.lang.String))(_.marker)
      .build()
  }
  def asReadOnly
      : zio.aws.docdb.model.DescribeOrderableDbInstanceOptionsResponse.ReadOnly =
    zio.aws.docdb.model.DescribeOrderableDbInstanceOptionsResponse
      .wrap(buildAwsValue())
}
object DescribeOrderableDbInstanceOptionsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.docdb.model.DescribeOrderableDbInstanceOptionsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.docdb.model.DescribeOrderableDbInstanceOptionsResponse =
      zio.aws.docdb.model.DescribeOrderableDbInstanceOptionsResponse(
        orderableDBInstanceOptions.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        marker.map(value => value)
      )
    def orderableDBInstanceOptions
        : Option[List[zio.aws.docdb.model.OrderableDBInstanceOption.ReadOnly]]
    def marker: Option[String]
    def getOrderableDBInstanceOptions: ZIO[Any, AwsError, List[
      zio.aws.docdb.model.OrderableDBInstanceOption.ReadOnly
    ]] = AwsError.unwrapOptionField(
      "orderableDBInstanceOptions",
      orderableDBInstanceOptions
    )
    def getMarker: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("marker", marker)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.docdb.model.DescribeOrderableDbInstanceOptionsResponse
  ) extends zio.aws.docdb.model.DescribeOrderableDbInstanceOptionsResponse.ReadOnly {
    override val orderableDBInstanceOptions
        : Option[List[zio.aws.docdb.model.OrderableDBInstanceOption.ReadOnly]] =
      scala
        .Option(impl.orderableDBInstanceOptions())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.docdb.model.OrderableDBInstanceOption.wrap(item)
          }.toList
        )
    override val marker: Option[String] =
      scala.Option(impl.marker()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.docdb.model.DescribeOrderableDbInstanceOptionsResponse
  ): zio.aws.docdb.model.DescribeOrderableDbInstanceOptionsResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-docdb_2.13-5.17.188.1-sources.jar: zio/aws/docdb/model/DescribeOrderableDbInstanceOptionsResponse.scala <==
package zio.aws.docdb.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class DescribeOrderableDbInstanceOptionsResponse(
    orderableDBInstanceOptions: Optional[
      Iterable[zio.aws.docdb.model.OrderableDBInstanceOption]
    ] = Optional.Absent,
    marker: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.docdb.model.DescribeOrderableDbInstanceOptionsResponse = {
    import DescribeOrderableDbInstanceOptionsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.docdb.model.DescribeOrderableDbInstanceOptionsResponse
      .builder()
      .optionallyWith(
        orderableDBInstanceOptions.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.orderableDBInstanceOptions)
      .optionallyWith(marker.map(value => value: java.lang.String))(_.marker)
      .build()
  }
  def asReadOnly
      : zio.aws.docdb.model.DescribeOrderableDbInstanceOptionsResponse.ReadOnly =
    zio.aws.docdb.model.DescribeOrderableDbInstanceOptionsResponse
      .wrap(buildAwsValue())
}
object DescribeOrderableDbInstanceOptionsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.docdb.model.DescribeOrderableDbInstanceOptionsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.docdb.model.DescribeOrderableDbInstanceOptionsResponse =
      zio.aws.docdb.model.DescribeOrderableDbInstanceOptionsResponse(
        orderableDBInstanceOptions.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        marker.map(value => value)
      )
    def orderableDBInstanceOptions
        : Optional[List[zio.aws.docdb.model.OrderableDBInstanceOption.ReadOnly]]
    def marker: Optional[String]
    def getOrderableDBInstanceOptions: ZIO[Any, AwsError, List[
      zio.aws.docdb.model.OrderableDBInstanceOption.ReadOnly
    ]] = AwsError.unwrapOptionField(
      "orderableDBInstanceOptions",
      orderableDBInstanceOptions
    )
    def getMarker: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("marker", marker)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.docdb.model.DescribeOrderableDbInstanceOptionsResponse
  ) extends zio.aws.docdb.model.DescribeOrderableDbInstanceOptionsResponse.ReadOnly {
    override val orderableDBInstanceOptions: Optional[
      List[zio.aws.docdb.model.OrderableDBInstanceOption.ReadOnly]
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.orderableDBInstanceOptions())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.docdb.model.OrderableDBInstanceOption.wrap(item)
        }.toList
      )
    override val marker: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.marker())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.docdb.model.DescribeOrderableDbInstanceOptionsResponse
  ): zio.aws.docdb.model.DescribeOrderableDbInstanceOptionsResponse.ReadOnly =
    new Wrapper(impl)
}
